@@ -5,3 +5,8 @@ semantic_palette <- c("#A333C8", "#21BA45", "#2185D0", "#DB2828", "#F2711C", "#F
                       "#00B5AD", "#6435C9", "#E03997", "#A5673F", "#767676", "#1B1C1D")
 names(semantic_palette) <- c("purple", "green", "blue", "red", "orange", "yellow", "olive", "teal",
                              "violet", "pink", "brown", "grey", "black")
+
+#' Checkbox positions
+#'
+#' @export
+checkbox_positions <- c("grouped", "inline")
