@@ -6,7 +6,9 @@ git checkout -B temp_cran_release
 
 echo "==> Preparing package for CRAN release."
 rm -r build/ docs/ examples/ LICENSE.md CHANGELOG.md README.Rmd README_files build_readme.R examples/ readme_assets/ readme_rmd_template/ inst/semantic/.versions
-sed -i '' '/^<link/d' README.md
+
+echo "==> Cleaning README"
+sed -i '' '/link href/d' README.md
 
 mkdir build
 
